#
# spec file for package keepass
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name KeePass
Name:           keepass
Version:        2.47
Release:        bp153.1.48
Summary:        Password Manager
License:        GPL-2.0-or-later
Group:          Productivity/Other
URL:            https://keepass.info/
Source0:        https://netcologne.dl.sourceforge.net/project/keepass/KeePass%202.x/%{version}/KeePass-%{version}-Source.zip
Source1:        https://keepass.info/integrity/v2/KeePass-%{version}-Source.zip.asc
# http://keepass.info/integrity/Dominik_Reichl.asc
Source2:        keepass.keyring
BuildRequires:  dos2unix
BuildRequires:  mono-devel
BuildRequires:  unzip
BuildRequires:  xdotool-devel
BuildRequires:  xorg-x11-fonts-core
BuildRequires:  xsel
Recommends:     xdotool
BuildArch:      noarch

%description
KeePass is a password manager, which helps you to manage your
passwords. You can put all your passwords in one database, which is
locked with one master key or a key file, so that you only have to
remember one single master password or select the key file to unlock
the whole database. The databases are encrypted using AES and
Twofish.

%prep
%setup -q -c %{name}-%{version}
dos2unix Docs/License.txt Docs/History.txt

sed -i '1s/ 10.00/ 11.00/' KeePass.sln
find . -name "*.csproj" -exec sed -i '1s/"3.5"/"4.0"/' {} +

pushd Build &>/dev/null
bash PrepMonoDev.sh
sh PrepMonoDev.sh
popd &>/dev/null

%build
xbuild /target:KeePass /property:Configuration=Release

%install
install -d %{buildroot}%{_prefix}/lib/%{name}
install -d %{buildroot}%{_prefix}/lib/%{name}/XSL
install -m 644 Build/%{_name}Lib_Distrib/%{_name}Lib.dll %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Build/%{_name}/Release/%{_name}.exe* %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/%{_name}.config.xml %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/%{_name}.exe.config %{buildroot}%{_prefix}/lib/%{name}/
install -m 644 Ext/XSL/* %{buildroot}%{_prefix}/lib/%{name}/XSL

# Bin wrapper
install -d %{buildroot}%{_bindir}
cat << EOF > %{buildroot}%{_bindir}/%{name}
#!/bin/sh
exec mono %{_prefix}/lib/%{name}/%{_name}.exe "\$@"
EOF

# Desktop file
install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Type=Application
Name=%{_name}
GenericName=Password Manager
Comment=Secure Password Management System
Icon=keepass
TryExec=%{_bindir}/keepass
Exec=keepass
Terminal=false
Categories=Utility;Security;
X-SuSE-translate=false
EOF

# Icon
install -d %{buildroot}%{_datadir}/pixmaps
install -m 644 Ext/Icons_04_CB/Finals/plock-blu.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%license Docs/License.txt
%doc Docs/History.txt
%attr(755,root,root) %{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_prefix}/lib/keepass

%changelog
* Sat Jan  9 2021 Matthias Bach <marix@marix.org> - 2.47
- Update to 2.47
  * New Features:
    + In the 'Find' dialog, search parameters can now be saved as profiles; the profiles can be accessed quickly via the main menu ('Find' → 'Search Profiles') and the group context menu.
    + Added search mode 'XPath expression' in the 'Find' dialog, which creates a KeePass 2.x XML DOM of the current database in memory and finds entries using the specified XPath expression.
    + Added option 'History' in the 'Find' dialog, which includes history entries in searches.
    + Added 'Help' button in the 'Find' dialog.
    + Added auto-type matching option 'Consider similar dashes as identical' (in 'Tools' → 'Options' → tab 'Advanced', turned on by default).
    + Added commands 'Copy Group (Encrypted)', 'Copy Group (Unencrypted)' and 'Paste Group' (in the menu 'Group' → 'Data Exchange').
    + When loading/saving a configuration file fails, an error message is displayed now, and in certain cases a backup of the configuration file is created (the path is mentioned in the error message).
    + Added configuration option for saving the configuration (turned on by default).
    + On the 'Security' tab page of the options dialog, two links have been added, which open help pages for experts and administrators.
    + Added {TIMEOTP} placeholder, which generates a time-based one-time password (as specified in RFC 6238).
    + Enhanced XML key file format (added hash that allows to verify the integrity of the key; values are now encoded using hexadecimal characters in order to improve the readability).
    + Added command 'Print Key File Backup' (in 'File' → 'Print').
    + In the dialog that asks whether to print an emergency sheet, there is now an option 'Also print a key file backup' (on Windows), if the master key contains a key file.
    + Added command 'Create Key File' (in 'Tools' → 'Advanced Tools'), which shows a dialog for creating a new key file (random key) or for recreating a key file from a printed backup.
    + Added Argon2id key derivation function.
    + Added support for importing Dashlane 6.2039.0 JSON files.
    + Dashlane and RoboForm import: domains are now mapped to HTTPS URLs (instead of HTTP URLs).
    + Added option 'Use a different master key' in the import/export dialog (tab page 'Options').
    + Added option 'Additionally export parent groups' in the import/export dialog (tab page 'Options').
    + Added options 'Open exported file (with associated application)' and 'Show exported file (with file manager)' in the import/export dialog (tab page 'Options').
    + The 'About' dialog now shows whether KeePass is currently running as 32- or 64-bit application.
    + Plugins can now disable/enable specific Mono workarounds.
    + Added workaround for Mono URL opening bug.
    + Added workaround for Mono HTML document opening bug.
  * Improvements:
    + Improved performance of certain searches.
    + Various user interface improvements in the search dialog.
    + Improved keyboard shortcut handling (e.g. Ctrl+Tab and Ctrl+Shift+Tab now also work when the quick search box is focused).
    + The local configuration file is now loaded only if necessary.
    + Improved performance of configuration saving.
    + Changed default key file extension from 'key' to 'keyx'.
    + Most key file dialogs now only show '*.keyx' and '*.key' files by default.
    + When clicking the key file 'Browse' button in the master key creation dialog and selecting a file that is not an XML key file, KeePass now asks whether to use the file as key file anyway.
    + Improved key file loading/saving error messages.
    + Various user interface improvements in the import/export dialog.
    + The import/export dialog does not accept relative file paths anymore.
    + The import/export dialog now shows an error message when trying to export to multiple files.
    + Removed indeterminate progress indicators while displaying the import/export dialog.
    + Improved field to standard field mapping function.
    + Moved command 'Empty Recycle Bin' directly below the 'Delete Group' command.
    + Moved commands 'Print Group' and 'Export Group' into the 'Data Exchange' popup menu.
    + Improved quality of some icons.
    + Improved dialog banner caching.
    + Improved performance of certain object collection operations.
    + History entry UUIDs are now fixed automatically.
    + Increased default value of Argon2 memory parameter.
    + Improved task dialog parent determination.
    + Various UI text improvements.
    + Various code optimizations.
    + Minor other improvements.
  * Bugfixes:
    + Search: regular expressions starting with a '-' are not treated as exclusions anymore.
    + Fixed a bug that caused KeePass to hang when trying to read a configuration file that contains certain unsupported nodes.
- Added _service file for easier source download.
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 2.46
- Make package conform to spec-cleaner.
* Sat Sep 12 2020 marix@marix.org - 2.46
- Update to 2.46
  * New Features:
    + The entry editing dialog can now edit all currently selected entries at once.
    + As entry attachment icons, the icons associated with the respective file types (in the system settings) are used now.
    + When running on .NET 4.8 or higher, secure connections (e.g. for WebDAV) now support TLS 1.3.
    + Added keyboard shortcut Ctrl+* (numeric keypad) for the 'Expand Recursively' group command.
    + Added keyboard shortcut Ctrl+/ (numeric keypad) for the 'Collapse Recursively' group command.
    + Right-clicking on the header of the main entry list now shows the 'Configure Columns' command.
    + The {VKEY ...} command now supports some flags (for specifying whether to send a key down or up event only and/or whether to send an extended key).
    + Added configuration option for protecting KeePass windows against certain screen capture operations.
    + Added command line parameter '-wa-enable:' for enabling specific Mono workarounds.
    + On Unix-like systems with a Wayland compositor, KeePass (with the KPUInput plugin) can now auto-type the default sequence and manually selected sequences of the currently selected entry.
  * Improvements:
    + Improved quality of the icons in the entry 'URL(s)' menu.
    + Improved quality of the icons in the drop-down list of the 'Override URL' field in the entry editing dialog.
    + Improved control state updating in the entry editing dialog.
    + The file selection dialog for the Generic CSV Importer now shows only CSV, TSV, TAB, TXT and ASC files by default.
    + Improved user interface of the Generic CSV Importer.
    + For large texts containing probably invalid characters, the internal data viewer now shortens the text and provides a 'Show more' link for expanding the text; this ensures a responsive user interface in this case.
    + Improved caching of dialog banners.
    + Moved the help source selection from the 'Help' main menu to the options dialog (tab 'Integration').
    + If the application policy option 'Export - No Key Repeat' is turned off, the master key must now be entered directly before the export is performed, i.e. after choosing the format and the target.
    + The application policy option 'Export - No Key Repeat' now also applies to the trigger action 'Export active database'.
    + When running on Mono, the options 'Focus quick search box when restoring from taskbar' and 'Focus quick search box when restoring from tray' are disabled now (because they do not work reliably due to a bug in Mono).
    + Various code optimizations.
    + Minor other improvements.
  * Bugfixes:
    + The attachment button drop-down menus in the entry editing dialog now use the correct font.
    + The 'Tools' button in the entry editing dialog is not disabled for TAN entries anymore.
* Sun May 10 2020 Matthias Bach <marix@marix.org>
- Update to 2.45
  * New Features:
    + Added automatic assignment of mnemonics for 'Open with ...' commands in the 'URL(s)' menu.
    + The entry templates menu now supports showing templates that are stored in subgroups of the templates group; each subgroup is displayed as a submenu.
    + When adding a new entry based on a template that has an empty user name, the user name is now set to the default user name of the database, unless the new entry is stored in the templates group.
    + When adding a new entry based on a template that has an empty password, a random password is generated now (based on the password generator profile 'Automatically generated passwords for new entries'), unless the new entry is stored in the templates group.
    + When adding a new entry based on a template that does not expire, the expiry date is now set based on the option 'By default, new entries expire in the following number of days' (in 'Tools' → 'Options' → tab 'Security'), unless the new entry is stored in the templates group.
    + New icon recoloring (with high DPI support, by deconstructing an ICO, modifying BMP palettes and data, and assembling a new ICO); there are 24 database colors now.
    + Added {UUID} placeholder, which is replaced by the UUID of the current entry.
    + The UUID of a group is now displayed in the group editing dialog (tab 'General').
    + When specifying a weak master password in the master key creation dialog, KeePass now shows a warning.
    + Triggers: added string comparison mode 'Matches regular expression'.
    + Enforced configuration: added support for attributes that allow to specify the desired merge behavior.
    + Enforced configuration: for most lists, node keys are now used to find corresponding list items.
    + Plugins: added I/O connection event for customizing web requests.
    + Added workaround for Mono pre-authenticated anonymous web request bug.
  * Improvements:
    + Auto-Type: improved compatibility with VMware Horizon Client and Kaseya Live Connect.
    + The 'Open with ...' commands in the 'URL(s)' menu are sorted now.
    + Improved performance of the entry templates menu; removed limitation to 30 templates.
    + Database descriptions are now displayed in file tab tooltips.
    + When editing an attachment directly from the main window, a history entry is created now.
    + UUIDs in the group and entry editing dialogs are now displayed both in hexadecimal and base 64 form.
    + Improved Bitwarden import module to support JSON files without groups.
    + If the trigger system is disabled using an enforced configuration file, most controls in the triggers dialog are disabled now, too.
    + Plugins: an I/O access event is now raised when checking the existence of a local database file.
    + In texts that are about to be displayed in a rich text box, U+FFFC characters are now replaced by question marks (in order to avoid the text being cut off at this point).
    + When running on Mono 5.10 or higher, a monospaced font is used in password text boxes by default again, as the Mono bug 5795 has been fixed.
    + Various code optimizations.
    + Minor other improvements.
  * Bugfixes
    + Fixed a default value type problem in the hot key configuration settings.
    + Database file tab colors are now rounded to the nearest supported colors.
* Wed Jan 22 2020 Matthias Bach <marix@marix.org>
- Update to 2.44
  * New Features:
    + Added option 'Use file transactions for writing configuration settings' (turned on by default).
    + Added commands to find database files ('File' → 'Open' → 'Find Files' and 'Find Files (In Folder)').
    + Added 'Edit' menu in the internal text editor (including new 'Select All' and 'Find' commands with keyboard shortcuts).
    + Added keyboard shortcuts for formatting commands in the internal text editor.
    + Added 'Cancel' button in the save confirmation dialog of the internal text editor.
    + Added {CLIPBOARD} and {CLIPBOARD-SET:/T/} placeholders, which get/set the clipboard content.
    + Added support for importing True Key 4 CSV files.
    + Added command line options for adding/removing scheme-specific URL overrides.
    + Added an auto-type event for plugins.
    + When loading a plugin on a Unix-like system fails, the error message now includes a hint that the 'mono-complete' package may be required.
    + In order to avoid a Windows Input Method Editor (IME) bug (resulting in a black screen and/or an IME/CTF process with high CPU usage), KeePass now disables the IME on secure desktops.
  * Improvements:
    + Auto-Type: improved compatibility with VMware Workstation.
    + Auto-Type into virtual machines: improved compatibility with certain guest systems.
    + The option to use the 'Clipboard Viewer Ignore' clipboard format is now turned on by default.
    + Improved menu/toolbar item state updating in the internal text editor.
    + Improved performance of Spr compilations.
    + Before writing a local configuration file whose path has been specified using the '-cfg-local:' command line parameter, KeePass now tries to create the parent directory, if it does not exist yet.
    + Improved conversion of file URIs to local file paths.
    + Improved compatibility of the list view dialog with plugins.
    + If ChaCha20 is selected as file encryption algorithm, the database is now saved in the KDBX 4 format (thanks to AMOSSYS).
    + Minor process memory protection improvements.
    + HTML export/printing: KeePass now generates HTML 5 documents (instead of XHTML 1.0 documents).
    + HTML export/printing: improved internal CSS.
    + HTML exports do not contain temporary content identifiers anymore.
    + XSL files: HTML output now conforms to HTML 5 instead of XHTML 1.0.
    + XSL files: improved internal CSS.
    + CHM pages are now rendered in the highest standards mode supported by Internet Explorer (EdgeHTML mode).
    + Migrated most of the documentation from XHTML 1.0 to HTML 5.
    + Various code optimizations.
    + Minor other improvements.
  * Bugfixes:
    + In the internal text editor, the 'Delete' command does not reset RTF text formattings anymore.
    + The KeyCreationFlags bit 219 (for hiding the passwords) now works as intended.
* Mon Dec 30 2019 Matthias Bach <marix@marix.org>
- Update to 2.43
  * New Features:
    + Added tooltips for certain character set options in the password generator dialog.
    + Added option 'Remember password hiding setting in the main window' (in 'Tools' → 'Options' → tab 'Advanced'; the option is turned on by default).
    + Added yellow intermediate step in password quality progress bars.
    + When the URL override field in the entry editing dialog is not empty, but the URL field is empty, a warning is displayed now.
    + When an explicit request to generate a password fails (for instance due to an invalid pattern), an error message is displayed now.
    + Added trigger events 'Synchronizing database file' and 'Synchronized database file'.
    + Enhanced the Password Agent import module to support XML files created by version 3.
    + The 'MasterKeyExpiryRec' configuration setting can now also be set to an XSD duration instead of an XSD date (for periodic master key change recommendations).
    + On Unix-like systems, file transactions now preserve the Unix file access permissions, the user ID and the group ID.
    + Added workaround for .NET initial focus bug.
  * Improvements:
    + Auto-Type: improved sending of modifier keys.
    + Auto-Type: improved sending of characters that are realized with Ctrl+Alt/AltGr.
    + Auto-Type: improved compatibility with VMware Remote Console and Dameware Mini Remote Control.
    + Improved main window state handling.
    + Improved construction and updates of the main menu and the group/entry context menus.
    + Main menu items can now be deselected by pressing the Esc key.
    + Top-level nodes in tree views cannot be collapsed anymore if no root lines are displayed.
    + New entries in a group with the e-mail folder icon now have the e-mail icon by default.
    + Improved performance of automatic scrolling in the main entry list.
    + If user names are hidden in the main window, no user name suggestions are displayed in the entry editing dialog anymore.
    + Function keys without modifiers can be registered as system-wide hot keys now.
    + For file rename/move web requests, a canonical representation of the destination name/path is used now.
    + URL override base placeholders can now be used within {CMD:...} placeholders.
    + Directly after an import, the deleted object information is now applied/removed (depending on the last modification time and the deletion time).
    + Improved compatibility of the 'Delete Duplicate Entries' command with the process memory protection.
    + Improved handling of command lines containing quotes or backslashes.
    + Various UI text improvements.
    + Various code optimizations.
    + Minor other improvements.
* Wed Jun 19 2019 Matthias Bach <marix@marix.org>
- Update to 2.42.1
  New Features:
  * Added main menu items 'Group', 'Entry' and 'Find', which contain all commands related to groups and entries (supersets of context menus); removed 'Edit' main menu item, because all of its commands are included in the three new main menu items.
  * Added support for a system-wide hot key to auto-type only the password of a matching entry; by default, the hot key is Ctrl+Alt+Shift+A, changeable in the options dialog.
  * When double-clicking the URL cell of an entry in the main entry list while holding down the Shift key, KeePass now copies the URL to the clipboard (a double-click without Shift continues to open the URL; the option 'Copy URLs to clipboard instead of opening them' reverses this behavior).
  * Added quick edit commands 'Expires: Now' and 'Expires: Never'.
  * There now are two commands for copying a whole entry to the clipboard: 'Copy Entry (Encrypted)' and 'Copy Entry (Unencrypted)'; the first one encrypts the data for the current user using the Windows DPAPI.
  * Added Ctrl+Shift+P shortcut for printing the currently selected group.
  * The creation time and the last modification time of an entry are now displayed on the 'History' tab of the entry editing dialog.
  * Added support for importing Steganos Password Manager 20 CSV files.
  * Added support for importing Bitwarden 1.12 JSON files.
  * Mozilla Bookmarks JSON import: added support for importing tags (new format, in addition to the old format) and keywords.
  * Enhanced the Enpass import module to support TXT files created by version 6.0.4.
  * The language selection dialog now also lists KeePass 1.x LNG files; when trying to select such a file, an informative error message is displayed.
  * Added 'Cancel' command in the context menu of KeePass' system tray icon, which can be used to abort opening and saving a database file.
  * Added '-cancel' command line option, which causes all other KeePass instances to cancel opening/saving a database file.
  * Added '-auto-type-password' command line option (other running KeePass instances auto-type only the password of a matching entry).
  * Added '-e1:' command line parameter, which works like '-e:', but is handled by only one other instance; '-e:' is handled by all other instances.
  * When compiling a PLGX plugin, KeePass now defines a 'KP_V_*_*_*' symbol, where the asterisks specify the KeePass version (for example, 'KP_V_2_42_0' for version 2.42).
  * Added workarounds for .NET Caps Lock warning tooltip bug.
  * Added workaround for Mono grid view default color bug.
  * Added workaround for OneDrive bug on Windows 1809.
  Improvements:
  * Auto-Type: improved sending of characters that are realized with the AltGr key.
  * Auto-Type: improved compatibility with VirtualBox 6 and VMware Player.
  * Improved user interface behavior while opening a database file.
  * Accelerator key improvements.
  * Replaced 4 and 8 weeks expiry date search commands by 1 and 2 months (taking the number of days in the months into account).
  * Improved hot key controls (better key combination handling and display).
  * The hot key controls in the options dialog now support entering hot keys that are already registered by KeePass.
  * Improved field to standard field mapping function.
  * Improved new-line handling of several import modules.
  * When a file import fails, KeePass now shows a more detailed error message.
  * After changing the color of an entry using a quick edit command, the entries are deselected now, such that the new color is visible immediately.
  * Moved 'Print Emergency Sheet' command into 'File' → 'Print'.
  * The pattern-based password generator now supports repeating escaped characters using '{...}'.
  * The pattern-based password generator now refuses to generate a password if the pattern is (partially) invalid.
  * Turning off the 'Unhide Passwords' policy now enforces hiding passwords in a few more places/situations.
  * New-line characters at the end of the output of a {CMD:...} placeholder are now removed (analogous to $(...) and `...` shell command substitutions).
  * The {URL:SCM} and {BASE:SCM} placeholders now work with arbitrary data having a ':'-terminated prefix.
  * Improved {URL:RMVSCM} and {BASE:RMVSCM} placeholders ('//' authority prefix is removed, but not '/').
  * The '-entry-url-open' command line option is now handled by all other KeePass instances (instead of only one).
  * Path traversal with attachment names is not possible anymore.
  * Removed the option 'Show tray icon only if main window has been sent to tray' from the options dialog (due to possible denial-of-service problems); if you want to hide the icon, it is recommended to configure this in the system settings instead.
  * Improved reading of KDBX XML documents with unknown elements.
  * Improved JSON parser.
  * Various UI text improvements.
  * Various code optimizations.
  * Improved menu item state updating.
  * Improved backward compatibility with certain plugins.
  Bugfixes:
  * Fixed a crash that could occur when trying to import certain Mozilla Bookmarks JSON files.
  * Fixed a crash that could occur when trying to import certain files with very deeply nested groups.
  * Fixed handling of paths with folder/file names containing quotes (which can occur on Unix-like systems only).
* Sun Mar 31 2019 Matthias Bach <marix@marix.org>
- Make the package recommend the xdotool package as, while the core
  functionality works fine with out it, auto type only works if
  xdotool is present on the system.
* Mon Jan 14 2019 René Linder <rene.linder@lihaso.ch>
- Update to 2.41
  New Features:
  * Added option 'Do not store data in the Windows clipboard history and the cloud clipboard' (the option is turned on by default; for entry clipboard commands in the main window).
  * Added option 'Esc keypress in main window' (in 'Tools' → 'Options' → tab 'Interface'), which allows to specify the action of the Esc key (ignore, lock workspace, minimize, minimize to tray, exit).
  * Added option 'Ignore search settings of groups' in the 'Find' dialog.
  * Internal data viewer: added support for zooming images using the OEM + and - keys with Ctrl.
  * Added accelerator keys (especially for labels) in various dialogs.
  * Added UIFlags bit for disabling the 'Database Settings' menu item.
  * Added workarounds for Windows RTF character encoding bug.
  * Added workaround for Mono input focus restoration problem that occurs when a form gets activated.
  * Plugins: added method to provide menu items.
  * Plugins: added property to get the edit mode of an entry dialog.
  * TrlUtil: added tab 'Validation', which shows the results of all checks that TrlUtil performs.
  * TrlUtil: the tab in the preview form that contains the currently selected control is now selected automatically.
  * TrlUtil: the preview form now shows accelerator keys permanently.
  * TrlUtil: enhanced support for derived control classes.
  * TrlUtil: the current file name is now displayed in the title bar.
  * Enhanced installer (added user directory checks, added option to open the plugins web page, component/option names can be translated now, updated NGen size estimation, improved file associations update, ...).
  Improvements:
  * In order to avoid selection/Ctrl+A problems, the user name auto-completion now does not append suggestions anymore; it only shows a list of suggestions (in which a suggestion can be selected manually).
  * Improved accelerator keys in the 'Find' dialog.
  * The history list in the entry dialog now supports showing custom icons.
  * Mass entry modifications (colors/icons) now create history entries, if necessary.
  * Improved text rendering in dialog banners.
  * In the database settings dialog, the path of the database file is now shown in the dialog banner.
  * Improved selection/view preservation of the entry view.
  * While importing/synchronizing, a status dialog is displayed now if and only if the main window is not constructed completely yet (otherwise the status is displayed in the main window).
  * Improved reliability of clipboard operations.
  * Improved error reporting for the 'Paste Entries' command.
  * Renamed the automatic clipboard clearing option and added a tooltip in order to clarify the behavior of the option.
  * The commands 'Find Similar Passwords (Pairs)', 'Find Similar Passwords (Clusters)' and 'Password Quality Report' now ignore TAN entries.
  * The report of clusters of similar passwords now shows more clusters in certain cases.
  * In the 'Plugins' dialog, the plugins are now sorted alphabetically.
  * KeePass does not try to load satellite assemblies as plugins anymore.
  * Improved configuration saving when an enforced configuration file exists, but no global one.
  * Improved reading of KDBX XML documents with unknown elements.
  * The export module 'Customizable HTML File' now works fine on Unix-like systems, too.
  * On Unix-like systems: improved support for executing KeePass while no X server is running.
  * ShInstUtil: improved NGen detection on 64-bit systems.
  * TrlUtil: the preview form does not steal the input focus anymore.
  * TrlUtil: improved accelerator key check.
  * Various code optimizations.
  * Minor other improvements.
  Bugfixes:
  * Fixed a bug that caused KeePass to crash when trying to view certain password generator profiles.
  * The option 'Use monospace font for passwords' in the 'Print' / HTML export dialog now works for all translations.
* Sat Sep 22 2018 daiaji mark <hentaiwushuang@gmail.com>
- Update to 2.40
  New Features:
  * Added automatic completion support for the user name box in the entry editing dialog and the auto-type sequence boxes in the entry/group editing dialogs (suggesting user names and auto-type sequences that are used in other entries/groups).
  * Added automatic completion support for the URL and user name boxes in the 'Open From URL' dialog (suggesting URLs and user names of items in the list of most recently used database files).
  * Added option 'Group path' in the 'Find' dialog (enabled by default for quick searches).
  * Added read-only mode for the entry string dialog, which is used by the entry dialog when viewing a history entry.
  * The internal data viewer now supports zooming images using Ctrl+Add, Ctrl+Subtract and the mouse wheel with Ctrl; furthermore, there are now '+' and '-' buttons right of the zoom selection box in the toolbar.
  * Added option 'Remember master password (in encrypted form) of a database while it is open' (which is the default; turning off this option prevents the usage of certain features).
  * Enhanced compatibility check for DLL plugins.
  * Added URL opening event for plugins.
  * On Unix-like systems: added support for opening the local help file with KChmViewer.
  * Added workaround for initial input focus problem in the master key prompt dialog.
  * Added workaround for Mono not always raising the FormClosed event properly.
  * TrlUtil now remembers the last translation file directory.
  Improvements:
  * The 'Configure Columns' dialog now computes a display order for the new columns, taking the previous display order into account.
  * While importing/synchronizing, no status dialog is displayed anymore (the status is displayed in the main window).
  * Improved UI responsiveness during long operations.
  * When hiding/restoring the main window via the system tray icon fails, KeePass now shows a notification.
  * Improved Return key handling in text boxes.
  * Improved initial input focus in some dialogs.
  * Enhanced database file path unification.
  * The configuration system does not create a KeePass folder in the user's application data folder anymore when the target configuration file location is outside this folder.
  * Improved window text query method.
  * Improved Unicode environment detection.
  * Various improvements for right-to-left writing systems.
  * Improved support for case-sensitive command line parameter names (for plugins and KPScript).
  * If a plugin is available both as a DLL and as a PLGX (in the same folder), KeePass now loads either the DLL or the PLGX.
  * For plugins: most public definitions are now static.
  * KPScript: improved parsing of escape sequences.
  * Renamed native support library item in the installer.
  * Upgraded installer.
  * Various code optimizations.
  * Minor other improvements.
  Bugfixes:
  * (None).
* Mon May  7 2018 idonmez@suse.com
- Update to 2.39
  New features
  * KeePass now uses Transactional NTFS (TxF) for writing database
    and configuration files, if possible; this improves the
    compatibility with other programs that are watching these
    files (e.g. file synchronization services).
  * Added command 'Edit' → 'Show Entries' → 'Large Entries'.
  * Added command 'Edit' → 'Show Entries' → 'Last Modified Entries'.
  * Added option 'Automatically save after modifying an entry
    using the entry editing dialog' (turned off by default).
  * Added option 'Minimize main window after performing auto-type'
    (turned off by default).
  * Added option 'Show lines between nodes in tree views'
    (turned off by default).
  * Added support for importing Google Chrome 66 password CSV files.
  * Added trigger event 'Time - Periodic', which is raised at
    user-defined intervals.
  * Links in the entry string editing dialog are clickable now.
  * Added UIFlags bit for disabling the 'XML Replace' menu item.
  * Added UIFlags bit for hiding auto-type obfuscation
    compatibility information dialogs.
  * Added workaround for .NET 'urtf' RTF round-trip bug.
  * Secure edit controls are now extensible by plugins.
  * KPScript: the 'AddEntry' command now supports the
    '-setx-Expires' and '-setx-ExpiryTime' parameters.
  Improvements
  * In printouts and HTML exports, expired entries now have a red
    'X' icon (if the option 'Icon' is turned on).
  * Improved string normalization in the entry and string editing dialogs.
  * Improved and optimized process memory protection, especially in the
    entry editing dialog.
  * Secure edit control improvements.
  * Improved behavior when moving a custom string to a standard field.
  * Improved entry size calculation.
  * URL overrides are now used also for application URLs.
  * Improved input focus restoration.
  * When trying to toggle the auto-start option and creating/deleting
    the registry value fails, KeePass now shows a detailed error message.
  * Improved XML serialization.
  * Stream disposal improvements in exceptional situations.
  * Process object disposal improvements.
  * Extended inter-process communication (IPC) messages are compressed
    and encrypted now.
  * New IPC mechanism on Unix-like systems.
  * Enhanced desktop type detection on Unix-like systems.
  * On the Cinnamon desktop, the 'Always on Top' option is now disabled
    (because it is not supported properly by the environment).
  * KeePass now ignores hidden Git and Visual Studio directories when
    building a PLGX file.
  * The trigger system now ignores state-changing placeholders in most places.
  * Removed trigger event 'User interface state updated'
    (consider using the new event 'Time - Periodic' instead).
  * Various code optimizations.
  * Minor other improvements.
  Bugfixes
  * The 'View' button on the 'History' tab of the entry editing dialog is now
    disabled when multiple items are selected.
  * The main window state is now updated after closing an entry report dialog.
* Wed Jan 10 2018 idonmez@suse.com
- Update to 2.38
  New features:
  * Added button 'Open Folder' in the language selection dialog,
    which opens the 'Languages' folder.
  * Added button 'Open Folder' in the plugins dialog,
    which opens the 'Plugins' folder.
  * Added option 'Icon' and an option for specifying the placeholder
    behavior (replace or not, or both forms) in the 'Print' / HTML
    export dialog.
  * Printing / HTML export: the notes of a group are now displayed
    below the group name.
  * Enhanced the Password Exporter import module to support XML
    files created by version 1.3.4.
  * Added workaround for Mono list view item deletion bug.
  * Added workaround for Mono command line argument encoding bug.
  Improvements:
  * Password quality estimation: improved compatibility with
    process memory protection.
  * Improved UI scaling when using KeePass on multiple systems
    with different DPI values.
  * Printing / HTML export: improved embedding of CSS.
  * Printing / HTML export: spaces in passwords are now encoded
    as non-breaking spaces.
  * Improved UI updating in the 'Print' / HTML export dialog.
  * Enhanced KDE system font detection.
  * Improved fatal error handling.
  * Various improvements in the language selection dialog.
  * Various code optimizations.
  * Minor other improvements.
  Bugfixes:
  * Fixed HTML generation bug: when the option 'Use monospace
    font for passwords' was turned off, a generated HTML file
    in 'Details' mode could contain invalid end tags
* Thu Oct 12 2017 idonmez@suse.com
- Update to 2.37
  New features:
  * When creating a new database, KeePass now offers to print a
    KeePass emergency sheet (which can then be filled out and
    stored in a secure location, where only the user and possibly
    a few other people that the user trusts have access to);
    an emergency sheet can also be created via
    'Tools' -> 'Database Tools' -> 'Print Emergency Sheet'.
  * Added database file information dialog that is displayed
    when creating a new database.
  * Added function to search similar password clusters
  ('Edit' -> 'Show Entries' -> 'Find Similar Passwords (Clusters)').
  * On Unix-like systems: if the library 'libgcrypt.so.20' is
    available, KeePass uses it for AES-KDF transformations.
  * Added workaround for .NET/Windows column header drawing bug
    when switching to TAN-only entry list mode.
  * Added workaround for Mono tab switching bug.
  * Added workaround for Mono '}' character RTF encoding bug.
  * TrlUtil: added support for .NET 4.*.
  Improvements:
  * Improved dialog for changing the master key
  * KeePass now directly offers to save the database after
    changing the master key, and it asks whether to print a
    new emergency sheet.
  * Various improvements in the translation selection dialog
  * KeePass now refuses to attach files that are larger than
    512 MB (as larger files can result in serialization problems).
  * Increased default number of AES-KDF rounds.
  * On Unix-like systems, KeePass now uses the CSP implementation
    of the AES algorithm for encrypting data, which is a bit faster.
  * Improved tool strip checkmark rendering on Unix-like systems.
* Sat Jun 10 2017 idonmez@suse.com
- Update to 2.36
  * See http://keepass.info/news/n170609_2.36.html for the
    complete changelog.
* Mon Jun  5 2017 idonmez@suse.com
- Fix install with Mono 5.0 (mdb files are not built anymore.)
* Fri May 19 2017 idonmez@suse.com
- Depend on mono-devel instead of monodevelop
* Mon Jan  9 2017 idonmez@suse.com
- Update to version 2.35
  * ChaCha20 and Argon2 support
  * See http://keepass.info/news/n170109_2.35.html for the changelog.
* Thu Dec 15 2016 jengelh@inai.de
- Trim filler words from description
* Sat Jun 11 2016 idonmez@suse.com
- Update to version 2.34
  * See http://keepass.info/news/n160611_2.34.html for details.
* Sat May  7 2016 idonmez@suse.com
- Update to 2.33
  * See http://keepass.info/news/n160507_2.33.html for the changelog.
* Thu Mar 10 2016 idonmez@suse.com
- Update to version 2.32
  * See http://keepass.info/news/n160309_2.32.html for the changelog.
- Remove Requires on libgdiplus-devel, this is fixed in Mono some
  time ago.
* Tue Jan 12 2016 t.gruner@katodev.de
- update to 2.31 (2016-01-09)
  - Added menu/toolbar styles, freely selectable in 'Tools' ->
    'Options' -> tab 'Interface'; available styles are 'Windows
    10', 'Windows 8.1', 'KeePass - Gradient', '.NET/Office -
    Professional' and 'System - Classic'; by default KeePass uses
    the style most similar to the one of the current operating
    system
  - Refined application icons (thanks to Victor Andreyenkov)
  - Auto-Type: new target window classification method, which
    improves compatibility with target windows hosted within
    other windows (e.g. a PuTTY window within SuperPuTTY/MTPuTTY)
  - Auto-Type: added workaround for the default Ctrl+Alt behavior
    of KiTTY variants (which differs from Windows' behavior)
  - Before clearing the clipboard, KeePass now first copies a
    non-sensitive text into it; this ensures that no sensitive
    information remains in the clipboard even when clearing is
    prevented by the environment (e.g. when running in a virtual
    machine, when using a clipboard extension utility, ...)
  - Added support for opening entry URLs with Internet Explorer
    or Google Chrome in private mode via the context menu ->
    'URL(s)' -> 'Open with ... (Private)'
  - Added URL override suggestions for Internet Explorer and
    Google Chrome in private mode in the URL override suggestions
    drop-down list in the entry dialog
  - Added optional built-in global URL overrides for opening
    HTTP/HTTPS URLs with Internet Explorer or Google Chrome in
    private mode
  - Added Ctrl+K shortcut for the 'Duplicate Entry' command
  - Mozilla Bookmarks HTML import: added support for importing
    tags
  - Added support for exporting to Mozilla Bookmarks HTML files
  - Windows/IE favorites export: entry fields are Spr-compiled
    now, and entries with cmd:// URLs are now exported as LNK
    files
  - HTML export/printing: added support for UUIDs, added
    horizontal lines between entries in details mode, added
    background color for group headings, long field names are
    hyphenated now, and long field data now breaks and wraps onto
    the next line
  - Plugins: added possibility to configure file transactions for
    each URI scheme
  - Plugins: added possibility to provide custom 'Save As'
    dialogs more easily
  - Converted some PNG images as a workaround for a problem in
    Cairo/LibPNG on Unix-like systems
  - As a workaround for a weakness in Mono's FileDialog, before
    showing such a dialog on Unix-like systems KeePass now tries
    to load the file '~/.recently-used' and deletes it, if it is
    not a valid XML file
  - KPScript: added support for specifying the master password in
    encrypted form using the '-pw-enc:' command line parameter
    (exactly like in KeePass, compatible with the {PASSWORD_ENC}
    placeholder)
  - KPScript: the 'Export' command now supports the optional
    '-GroupPath:' parameter (to export a specific group instead
    of the whole database)
  - KPScript: the 'GetEntryString' command now supports the
    '-FailIfNoEntry' option
  - KPScript: added '-refx-Expires' and '-refx-Expired' entry
    identification parameters
  - KPScript: the 'Import' command now prints more specific error
    messages
  - All KeePass program binaries are now dual signed using SHA-1
    and SHA-256
  - Auto-Type: improved keyboard layout handling when the target
    window changes during an auto-type process
  - Auto-Type: improved compatibility with Remote Desktop
    Connection client and VirtualBox
  - Improved icon recoloring
  - Improved printing of dates/times and tags
  - The password generator based on a character set now ensures
    that the generated password is Spr-invariant
  - Password generator based on a pattern or a custom algorithm:
    when a Spr-variant password is generated, a confirmation
    dialog for accepting this password is displayed
  - If the 'Save Database' policy prevents saving, the auto-save
    option is now ignored
  - Improved .NET Framework version detection
  - PLGX debugging: when the command line option '-debug' is
    passed and a PLGX plugin fails to compile, the output of all
    tried compilers is saved to a temporary file
  - Improved file transaction creation time handling on Unix-like
    systems
  - Improved compatibility with Mono on BSD systems
  - Enhanced PrepMonoDev.sh script for compatibility with Mono
    4.x
  - Removed KeePassLibSD sub-project (a KeePass library for
    Pocket PC / Windows Mobile) from the main solution
  - Upgraded installer
  - Various code optimizations
  - Minor other improvements
  - When running under Mono (Linux, Mac OS X, ...), two options
    related to window minimization are disabled now (because they
    do not work properly due to a Mono bug)
* Sun Sep  6 2015 t.gruner@katodev.de
- update to 2.30 (2015-08-09)
  - When opening a database via an URL fails, the error message
    dialog now has a button 'Specify different server
    credentials' (on Windows Vista and higher)
  - Added support for opening entry URLs with Microsoft Edge via
    the context menu -> 'URL(s)' -> 'Open with Edge'
  - Added URL override suggestion for Microsoft Edge in the URL
    override suggestions drop-down list in the entry dialog
  - Added optional built-in global URL overrides for opening
    HTTP/HTTPS URLs with Microsoft Edge
  - When clicking on a group link in the entry view, KeePass now
    ensures that the group is visible in the group tree
  - The main window is now moved onto the primary screen when it
    is restored outside all screens
  - KDBX loader: added support for non-empty protected binary
    value reference elements
  - Plugins: added two auto-type sequence query events
  - Added workaround for Mono drawing bug when scrolling a rich
    text box
  - When running under Mono, some automatic locking options are
    now disabled (because Mono doesn't implement the required
    events)
  - The installer now prevents running the installer while it is
    already running
  - KPScript: added '-GroupPath:' parameter (for specifying the
    full path of a group)
  - KPScript: the 'MoveEntry' command now also supports the
    '-GroupName:' parameter (as alternative to '-GroupPath:')
  - KPScript: added support for specifying the path of an XSL
    stylesheet file using the command line parameter '-XslFile:'
  - KPScript: the 'ListGroups' command now also outputs the
    parent group UUID for each group
  - KPScript: the parameters for specifying new field data (for
    the 'AddEntry' and the 'EditEntry' command) now support
    escape sequences (e.g. '\n' is replaced by a new-line
    character)
  - The 'Synchronize' file dialog now shows only KDBX files by
    default
  - In the 'Attachments (Count)' column, only non-zero counts are
    shown now
  - Improved MRU item refreshes
  - The entry string dialog now supports changing the case of a
    string name
  - The entry string dialog now does not allow adding a string
    whose name differs from another existing string name in this
    entry only by case
  - The entry view in the main window is now updated immediately
    after pressing Ctrl+H or Ctrl+J
  - The KDB import module now tries to round any invalid
    date/time to the nearest valid date/time
  - XML serializers are now loaded/created at KeePass startup in
    order to avoid a problem when shutting down Windows and
    KeePass.XmlSerializers.dll not being present
  - Changed tab bar behavior in the options dialog to avoid a tab
    content cropping issue caused by plugins
  - Improved workaround for Mono splitter bug
  - Upgraded installer
  - Various performance improvements
  - Various code optimizations
  - Minor other improvements
* Thu Apr 30 2015 t.gruner@katodev.de
- fix GPG validation
* Sat Apr 11 2015 mailaender@opensuse.org
- fix System.DllNotFoundException: libgdiplus.so
- don't use _service (not allowed in Factory)
- add GPG validation source file integrity checks
- update to 2.29
  * http://keepass.info/news/n150410_2.29.html
  * http://keepass.info/news/n141008_2.28.html
* Mon Jul 14 2014 altesholz@gmail.com
- update to 2.27
  - Changelog: http://keepass.info/news/n140706_2.27.html
* Sat May 10 2014 chris+dev@any.mx
- update to 2.26
  - Changelog: http://keepass.info/news/n140413_2.26.html
* Fri Feb 28 2014 chris+dev@any.mx
- update to 2.25
  - Changelog: http://keepass.info/news/n140203_2.25.html
- added download service
* Thu Jan 30 2014 peter.trommler@ohm-hochschule.de
- update to 2.24
- fix for broken png files
  * drop extra file with png images
- for changelog see: http://keepass.info/news/n131103_2.24.html
* Wed Oct 23 2013 peter.trommler@ohm-hochschule.de
- add archive with fixed png files (see bug #1168)
- remove dependency on pngcrush
* Sun Oct 20 2013 peter.trommler@ohm-hochschule.de
- update to 2.23
- fix png files (see https://bugs.gentoo.org/show_bug.cgi?id=472764)
* Sun Mar 10 2013 mailaender@opensuse.org
- update to 2.21
  - Changelog: http://keepass.info/news/n130203_2.21.html
- enable additional support for auto-type and clipboard operations
* Fri Oct 19 2012 adam@mizerski.pl
- update to 2.20.1
  - Improved support for images with DPI resolutions different from
    the DPI resolution of the display device.
  - {GOOGLECHROME} placeholder: updated detection code to also
    support the latest versions of Chrome.
  - The option to lock on remote control mode changes now
    additionally watches for remote connects and disconnects.
  - Improved Windows registry accesses.
  - Improved behavior when the user deletes the system temporary
    directory.
  - On Unix-like systems, KeePass now stores most of its temporary
    files in a private temporary directory (preferably in
    $XDG_RUNTIME_DIR).
  - Added detection support for the following web browsers on
    Unix-like systems: Rekonq, Midori and Dooble.
  - KeePass does not try to set the WM_CLASS property on Mac OS X
    systems anymore.
  - Modified some icons to work around unsupported PNG transparency
    keys in Mono.
  - Various code optimizations.
  - Minor other improvements.
* Sun Sep 30 2012 adam@mizerski.pl
- update to 2.20
* Thu Mar 11 2010 ajorgensen@novell.com
- Update to 2.10
